@@ -245,7 +245,9 @@ tibble::tribble(
   '`lavaan::lavaan()`', 'Limited support for categorical variables',
   '`cmprsk::crr()`', 'Limited support',
   '`stats::nls()`', 'Limited support',
-  '`lfe::felm()`', ''
+  '`lfe::felm()`', '',
+  '`rstanarm::stan_glm()`', '`broom.mixed` package required',
+  '`VGAM::vglm()`', 'Limited support. It is recommanded to use `tidy_parameters()` as `tidy_fun`.'
 ) %>%
   dplyr::arrange(Model) %>%
   gt::gt() %>%
