@@ -166,8 +166,8 @@ test_that("tidy_plus_plus() works with stats::aov", {
 test_that("tidy_plus_plus() works with lme4::lmer", {
   skip_on_cran()
   skip_if_not_installed("lme4")
-  mod <- lme4::lmer(Reaction ~ Days + (Days | Subject), lme4::sleepstudy)
   skip_if_not_installed("broom.mixed")
+  mod <- lme4::lmer(Reaction ~ Days + (Days | Subject), lme4::sleepstudy)
   expect_error(
     res <- mod %>% tidy_plus_plus(),
     NA
@@ -378,6 +378,23 @@ test_that("tidy_plus_plus() works with brms::brm", {
   )
 })
 
+test_that("tidy_plus_plus() works with rstanarm::stan_glm", {
+  skip_on_cran()
+  skip_if_not_installed("broom.mixed")
+  skip_if_not_installed("rstanarm")
+
+  mod <- rstanarm::stan_glm(
+    response ~ age + grade,
+    data = gtsummary::trial,
+    refresh = 0,
+    family = binomial
+  )
+  expect_error(
+    res <- mod %>% tidy_plus_plus(tidy_fun = broom.mixed::tidy),
+    NA
+  )
+})
+
 test_that("tidy_plus_plus() works with cmprsk::crr", {
   skip_on_cran()
   skip_if_not_installed("cmprsk")
@@ -483,3 +500,26 @@ test_that("tidy_plus_plus() works with mgcv::gam", {
   expect_error(tbl_gam_param_only <- gam_param_only %>% tidy_plus_plus(tidy_fun = tidy_gam), NA)
   # the default tidier return a df with no columns and no rows...it fails.
 })
+
+
+test_that("tidy_plus_plus() works with VGAM::vglm", {
+  skip_on_cran()
+  skip_if_not_installed("VGAM")
+  skip_if_not_installed("parameters")
+
+  df <- data.frame(
+    treatment = gl(3, 3),
+    outcome = gl(3, 1, 9),
+    counts = c(18,17,15,20,10,20,25,13,12)
+  )
+  mod <- VGAM::vglm(
+    counts ~ outcome + treatment,
+    family = VGAM::poissonff,
+    data = df,
+    trace = FALSE
+  )
+  expect_error(
+    res <- mod %>% tidy_plus_plus(),
+    NA
+  )
+})
